Examples
--------

All classes (except the reports class) correspond to one of the `Product Specific Scopus APIs <https://dev.elsevier.com/api_docs.html>`_.

There are Search APIs and Retrieval APIs. They have in common that the obtained result is cached in a subfolder in `~/.scopus/` on your hard drive. Subsequent analysis becomes much quicker this way. A boolean `refresh` parameter steers whether this file should be refreshed or not.

.. contents::


Search APIs
~~~~~~~~~~~

.. toctree::
    examples/AuthorSearch.rst
    examples/ScopusSearch.rst

One other Search API, Affiliation Search, is not implemented yet.


Retrieval APIs
~~~~~~~~~~~~~~

.. toctree::
    examples/ScopusAbstract.rst
    examples/ScopusAffiliation.rst
    examples/ScopusAuthor.rst


Metadata APIs
~~~~~~~~~~~~~

.. toctree::
    examples/CitationOverview.rst

Two other Metadata APIs, Serial Title Metadata and Subject Classifications, are not implemented yet.


report
~~~~~~

.. toctree::
    :maxdepth: 1

    examples/report.rst
